@@ -1,22 +1,25 @@
 package Devel::IPerl;
 # ABSTRACT: Perl language kernel for IPython
-$Devel::IPerl::VERSION = '0.005';
+$Devel::IPerl::VERSION = '0.006';
 use strict;
 use warnings;
 
 use Devel::IPerl::Kernel;
+use Devel::IPerl::NBConvert;
 
 sub main {
 	if ( @ARGV >= 1 ) {
 		if( @ARGV >= 2 and $ARGV[0] eq 'kernel' ) {
 			my $kernel = Devel::IPerl::Kernel->new( connection_file => $ARGV[1] );
 			$kernel->run;
+		} elsif( $ARGV[0] eq 'nbconvert.iperl' ) {
+			shift @ARGV;
+			Devel::IPerl::NBConvert->new()->run;
 		}
 	}
+	return 0;
 }
 
-main;
-
 1;
 
 __END__
@@ -31,7 +34,7 @@ Devel::IPerl - Perl language kernel for IPython
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 AUTHOR
 
